(v1.10.1)=
### 1.10.1 {small}`2024-04-09`

#### Documentation

* Added {doc}`how-to example </how-to/plotting-with-marsilea>` on plotting with [Marsilea](https://marsilea.readthedocs.io) {pr}`2974` {smaller}`Y Zheng`

#### Bug fixes

* Fix `aggregate` when aggregating by more than two groups {pr}`2965` {smaller}`I Virshup`


#### Performance
* {func}`~scanpy.pp.scale` now uses numba kernels for `sparse.csr_matrix` and `sparse.csc_matrix` when `zero_center==False` and `mask_obs` is provided. This greatly speed up execution {pr}`2942` {smaller}`S Dicks`
